==========
easyimages
==========


.. image:: https://img.shields.io/pypi/v/easyimages.svg
        :target: https://pypi.python.org/pypi/easyimages

.. image:: https://img.shields.io/travis/i008/easyimages.svg
        :target: https://travis-ci.org/i008/easyimages

.. image:: https://readthedocs.org/projects/easyimages/badge/?version=latest
        :target: https://easyimages.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status


.. image:: https://pyup.io/repos/github/i008/easyimages/shield.svg
     :target: https://pyup.io/repos/github/i008/easyimages/
     :alt: Updates



Images made easy





Features
--------

* TODO

Credits
-------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
